The following tasks implement delayed response paradigms:

- [GoNogo](../envs.md#neurogym.envs.native.gonogo.GoNogo)
- [IntervalDiscrimination](../envs.md#neurogym.envs.native.intervaldiscrimination.IntervalDiscrimination)
- [PerceptualDecisionMakingDelayResponse](../envs.md#neurogym.envs.native.perceptualdecisionmaking.PerceptualDecisionMakingDelayResponse)
- [PostDecisionWager](../envs.md#neurogym.envs.native.postdecisionwager.PostDecisionWager)
- [ReachingDelayResponse](../envs.md#neurogym.envs.native.reachingdelayresponse.ReachingDelayResponse)
